@@ -12,7 +12,7 @@ __all__ = ['newaxis', 'ndarray', 'flatiter', 'ufunc',
            'array_repr', 'array_str', 'set_string_function',
            'little_endian', 'require',
            'fromiter', 'array_equal', 'array_equiv',
-           'indices', 'fromfunction', 'loadtxt', 'savetxt',
+           'indices', 'fromfunction',
            'load', 'loads', 'isscalar', 'binary_repr', 'base_repr',
            'ones', 'identity', 'allclose', 'compare_chararrays', 'putmask',
            'seterr', 'geterr', 'setbufsize', 'getbufsize',
@@ -37,45 +37,53 @@ MAXDIMS = multiarray.MAXDIMS
 ALLOW_THREADS = multiarray.ALLOW_THREADS
 BUFSIZE = multiarray.BUFSIZE
 
+ndarray = multiarray.ndarray
+flatiter = multiarray.flatiter
+broadcast = multiarray.broadcast
+dtype = multiarray.dtype
+ufunc = type(sin)
 
-# from Fernando Perez's IPython
+
+# originally from Fernando Perez's IPython
 def zeros_like(a):
-    """Return an array of zeros of the shape and typecode of a.
+    """Return an array of zeros of the shape and data-type of a.
 
     If you don't explicitly need the array to be zeroed, you should instead
-    use empty_like(), which is faster as it only allocates memory."""
-    try:
-        return zeros(a.shape, a.dtype, a.flags.fnc)
-    except AttributeError:
-        try:
-            wrap = a.__array_wrap__
-        except AttributeError:
-            wrap = None
-        a = asarray(a)
-        res = zeros(a.shape, a.dtype)
-        if wrap:
-            res = wrap(res)
+    use empty_like(), which is a bit faster as it only allocates memory.
+    """
+    if isinstance(a, ndarray):
+        res = ndarray.__new__(type(a), a.shape, a.dtype, order=a.flags.fnc)
+        res.fill(0)
         return res
+    try:
+        wrap = a.__array_wrap__
+    except AttributeError:
+        wrap = None
+    a = asarray(a)
+    res = zeros(a.shape, a.dtype)
+    if wrap:
+        res = wrap(res)
+    return res
 
 def empty_like(a):
-    """Return an empty (uninitialized) array of the shape and typecode of a.
+    """Return an empty (uninitialized) array of the shape and data-type of a.
 
     Note that this does NOT initialize the returned array.  If you require
     your array to be initialized, you should use zeros_like().
 
     """
-    try:
-        return empty(a.shape, a.dtype, a.flags.fnc)
-    except AttributeError:
-        try:
-            wrap = a.__array_wrap__
-        except AttributeError:
-            wrap = None
-        a = asarray(a)
-        res = empty(a.shape, a.dtype)
-        if wrap:
-            res = wrap(res)
+    if isinstance(a, ndarray):
+        res = ndarray.__new__(type(a), a.shape, a.dtype, order=a.flags.fnc)
         return res
+    try:
+        wrap = a.__array_wrap__
+    except AttributeError:
+        wrap = None
+    a = asarray(a)
+    res = empty(a.shape, a.dtype)
+    if wrap:
+        res = wrap(res)
+    return res
 
 # end Fernando's utilities
 
@@ -97,11 +105,6 @@ extend_all(numerictypes)
 
 newaxis = None
 
-ndarray = multiarray.ndarray
-flatiter = multiarray.flatiter
-broadcast = multiarray.broadcast
-dtype = multiarray.dtype
-ufunc = type(sin)
 
 arange = multiarray.arange
 array = multiarray.array
@@ -147,6 +150,29 @@ def asfortranarray(a, dtype=None):
     return array(a, dtype, copy=False, order='F', ndmin=1)
 
 def require(a, dtype=None, requirements=None):
+    """Return an ndarray of the provided type that satisfies requirements.
+
+    This function is useful to be sure that an array with the correct flags
+    is returned for passing to compiled code (perhaps through ctypes).
+
+    Parameters
+    ----------
+     a : array-like
+       The object to be converted to a type-and-requirement satisfying array
+     dtype : data-type
+       The required data-type (None is the default data-type -- float64)
+     requirements : list of strings
+       The requirements list can be any of the
+       'ENSUREARRAY' ('E')  - ensure that  a base-class ndarray
+       'F_CONTIGUOUS' ('F') - ensure a Fortran-contiguous array
+       'C_CONTIGUOUS' ('C') - ensure a C-contiguous array
+       'ALIGNED' ('A')      - ensure a data-type aligned array
+       'WRITEABLE' ('W')    - ensure a writeable array
+       'OWNDATA' ('O')      - ensure an array that owns its own data
+
+       The returned array will be guaranteed to have the listed requirements
+       by making a copy if needed.
+    """
     if requirements is None:
         requirements = []
     else:
@@ -187,6 +213,13 @@ def argwhere(a):
     """Return a 2-d array of shape N x a.ndim where each row
     is a sequence of indices into a.  This sequence must be
     converted to a tuple in order to be used to index into a.
+
+    >>> from numpy import ones, argwhere
+    >>> argwhere(ones((2, 2)))
+    array([[0, 0],
+           [0, 1],
+           [1, 0],
+           [1, 1]])
     """
     return asarray(a.nonzero()).T
 
@@ -194,6 +227,12 @@ def flatnonzero(a):
     """Return indicies that are not-zero in flattened version of a
 
     Equivalent to a.ravel().nonzero()[0]
+
+    >>> from numpy import arange, flatnonzero
+    >>> arange(-2, 3)
+    array([-2, -1,  0,  1,  2])
+    >>> flatnonzero(arange(-2, 3))
+    array([0, 1, 3, 4])
     """
     return a.ravel().nonzero()[0]
 
@@ -255,8 +294,10 @@ try:
     from _dotblas import dot, vdot, inner, alterdot, restoredot
 except ImportError:
     def alterdot():
+        "Does Nothing"
         pass
     def restoredot():
+        "Does Nothing"
         pass
 
 
@@ -343,6 +384,12 @@ def tensordot(a, b, axes=2):
 def roll(a, shift, axis=None):
     """Roll the elements in the array by 'shift' positions along
     the given axis.
+
+    >>> from numpy import roll
+    >>> arange(10)
+    array([0, 1, 2, 3, 4, 5, 6, 7, 8, 9])
+    >>> roll(arange(10), 2)
+    array([8, 9, 0, 1, 2, 3, 4, 5, 6, 7])
     """
     a = asanyarray(a)
     if axis is None:
@@ -362,11 +409,14 @@ def roll(a, shift, axis=None):
 def rollaxis(a, axis, start=0):
     """Return transposed array so that axis is rolled before start.
 
-    if a.shape is (3,4,5,6)
-    rollaxis(a, 3, 1).shape is (3,6,4,5)
-    rollaxis(a, 2, 0).shape is (5,3,4,6)
-    rollaxis(a, 1, 3).shape is (3,5,4,6)
-    rollaxis(a, 1, 4).shape is (3,5,6,4)
+    >>> from numpy import ones, rollaxis
+    >>> a = ones((3,4,5,6))
+    >>> rollaxis(a, 3, 1).shape
+    (3, 6, 4, 5)
+    >>> rollaxis(a, 2, 0).shape
+    (5, 3, 4, 6)
+    >>> rollaxis(a, 1, 4).shape
+    (3, 5, 6, 4)
     """
     n = a.ndim
     if axis < 0:
@@ -565,7 +615,7 @@ def binary_repr(num, width=None):
             # replace num with its 2-complement
             num = 2**width + num
     elif num == 0:
-        return '0'
+        return '0'*(width or 1)
     ostr = hex(num)
     bin = ''.join([_lkup[ch] for ch in ostr[2:]])
     bin = bin.lstrip('0')
@@ -610,177 +660,6 @@ def load(file):
         file = _file(file,"rb")
     return _cload(file)
 
-# Adapted from matplotlib
-
-def _getconv(dtype):
-    typ = dtype.type
-    if issubclass(typ, bool_):
-        return lambda x: bool(int(x))
-    if issubclass(typ, integer):
-        return int
-    elif issubclass(typ, floating):
-        return float
-    elif issubclass(typ, complex):
-        return complex
-    else:
-        return str
-
-
-def _string_like(obj):
-    try: obj + ''
-    except (TypeError, ValueError): return 0
-    return 1
-
-def loadtxt(fname, dtype=float, comments='#', delimiter=None, converters=None,
-            skiprows=0, usecols=None, unpack=False):
-    """
-    Load ASCII data from fname into an array and return the array.
-
-    The data must be regular, same number of values in every row
-
-    fname can be a filename or a file handle.  Support for gzipped files is
-    automatic, if the filename ends in .gz
-
-    See scipy.loadmat to read and write matfiles.
-
-    Example usage:
-
-      X = loadtxt('test.dat')  # data in two columns
-      t = X[:,0]
-      y = X[:,1]
-
-    Alternatively, you can do the same with "unpack"; see below
-
-      X = loadtxt('test.dat')    # a matrix of data
-      x = loadtxt('test.dat')    # a single column of data
-
-
-    dtype - the data-type of the resulting array.  If this is a
-    record data-type, the the resulting array will be 1-d and each row will
-    be interpreted as an element of the array. The number of columns
-    used must match the number of fields in the data-type in this case. 
-    
-    comments - the character used to indicate the start of a comment
-    in the file
-
-    delimiter is a string-like character used to seperate values in the
-    file. If delimiter is unspecified or none, any whitespace string is
-    a separator.
-
-    converters, if not None, is a dictionary mapping column number to
-    a function that will convert that column to a float.  Eg, if
-    column 0 is a date string: converters={0:datestr2num}
-
-    skiprows is the number of rows from the top to skip
-
-    usecols, if not None, is a sequence of integer column indexes to
-    extract where 0 is the first column, eg usecols=(1,4,5) to extract
-    just the 2nd, 5th and 6th columns
-
-    unpack, if True, will transpose the matrix allowing you to unpack
-    into named arguments on the left hand side
-
-        t,y = load('test.dat', unpack=True) # for  two column data
-        x,y,z = load('somefile.dat', usecols=(3,5,7), unpack=True)
-
-    """
-
-    if _string_like(fname):
-        if fname.endswith('.gz'):
-            import gzip
-            fh = gzip.open(fname)
-        else:
-            fh = file(fname)
-    elif hasattr(fname, 'seek'):
-        fh = fname
-    else:
-        raise ValueError('fname must be a string or file handle')
-    X = []
-
-    dtype = multiarray.dtype(dtype)
-    defconv = _getconv(dtype)
-    converterseq = None    
-    if converters is None:
-        converters = {}
-        if dtype.names is not None:
-            converterseq = [_getconv(dtype.fields[name][0]) \
-                            for name in dtype.names]
-            
-    for i,line in enumerate(fh):
-        if i<skiprows: continue
-        line = line[:line.find(comments)].strip()
-        if not len(line): continue
-        vals = line.split(delimiter)
-        if converterseq is None:
-           converterseq = [converters.get(j,defconv) \
-                           for j in xrange(len(vals))]
-        if usecols is not None:
-            row = [converterseq[j](vals[j]) for j in usecols]
-        else:
-            row = [converterseq[j](val) for j,val in enumerate(vals)]
-        if dtype.names is not None:
-            row = tuple(row)
-        X.append(row)
-
-    X = array(X, dtype)
-    r,c = X.shape
-    if r==1 or c==1:
-        X.shape = max([r,c]),
-    if unpack: return X.T
-    else:  return X
-
-
-# adjust so that fmt can change across columns if desired. 
-
-def savetxt(fname, X, fmt='%.18e',delimiter=' '):
-    """
-    Save the data in X to file fname using fmt string to convert the
-    data to strings
-
-    fname can be a filename or a file handle.  If the filename ends in .gz,
-    the file is automatically saved in compressed gzip format.  The load()
-    command understands gzipped files transparently.
-
-    Example usage:
-
-    save('test.out', X)         # X is an array
-    save('test1.out', (x,y,z))  # x,y,z equal sized 1D arrays
-    save('test2.out', x)        # x is 1D
-    save('test3.out', x, fmt='%1.4e')  # use exponential notation
-
-    delimiter is used to separate the fields, eg delimiter ',' for
-    comma-separated values
-    """
-
-    if _string_like(fname):
-        if fname.endswith('.gz'):
-            import gzip
-            fh = gzip.open(fname,'wb')
-        else:
-            fh = file(fname,'w')
-    elif hasattr(fname, 'seek'):
-        fh = fname
-    else:
-        raise ValueError('fname must be a string or file handle')
-
-
-    X = asarray(X)
-    origShape = None
-    if len(X.shape)==1:
-        origShape = X.shape
-        X.shape = len(X), 1
-    for row in X:
-        fh.write(delimiter.join([fmt%val for val in row]) + '\n')
-
-    if origShape is not None:
-        X.shape = origShape
-
-
-    
-
-
-
-
 # These are all essentially abbreviations
 # These might wind up in a special abbreviations module
 
@@ -835,23 +714,21 @@ def allclose(a, b, rtol=1.e-5, atol=1.e-8):
     """
     x = array(a, copy=False)
     y = array(b, copy=False)
-    d1 = less_equal(absolute(x-y), atol + rtol * absolute(y))
     xinf = isinf(x)
-    yinf = isinf(y)
-    if (not xinf.any() and not yinf.any()):
-        return d1.all()
-    d3 = (x[xinf] == y[yinf])
-    d4 = (~xinf & ~yinf)
-    if d3.size < 2:
-        if d3.size==0:
-            return False
-        return d3
-    if d3.all():
-        return d1[d4].all() 
-    else:
+    if not all(xinf == isinf(y)):
         return False
+    if not any(xinf):
+        return all(less_equal(absolute(x-y), atol + rtol * absolute(y)))
+    if not all(x[xinf] == y[xinf]):
+        return False
+    x = x[~xinf]
+    y = y[~xinf]
+    return all(less_equal(absolute(x-y), atol + rtol * absolute(y)))
 
 def array_equal(a1, a2):
+    """Returns True if a1 and a2 have identical shapes
+    and all elements equal and False otherwise.
+    """
     try:
         a1, a2 = asarray(a1), asarray(a2)
     except:
@@ -861,6 +738,10 @@ def array_equal(a1, a2):
     return logical_and.reduce(equal(a1,a2).ravel())
 
 def array_equiv(a1, a2):
+    """Returns True if a1 and a2 are shape consistent
+    (mutually broadcastable) and have all elements equal and False
+    otherwise.
+    """
     try:
         a1, a2 = asarray(a1), asarray(a2)
     except:
@@ -899,10 +780,10 @@ def seterr(all=None, divide=None, over=None, under=None, invalid=None):
 
     >>> seterr(over='raise') # doctest: +SKIP
     {'over': 'ignore', 'divide': 'ignore', 'invalid': 'ignore', 'under': 'ignore'}
-    
+
     >>> seterr(all='warn', over='raise') # doctest: +SKIP
     {'over': 'raise', 'divide': 'ignore', 'invalid': 'ignore', 'under': 'ignore'}
-    
+
     >>> int16(32000) * int16(3) # doctest: +SKIP
     Traceback (most recent call last):
           File "<stdin>", line 1, in ?
