@@ -668,6 +668,19 @@ class TestClip(NumpyTestCase):
         self.clip(a, m, M, ac)
         assert_array_strict_equal(a, ac)
 
+    def test_clip_func_takes_out(self):
+        """ Ensure that the clip() function takes an out= argument.
+        """
+        a = self._generate_data(self.nr, self.nc)
+        ac = a.copy()
+        m = -0.5
+        M = 0.6
+        a2 = clip(a, m, M, out=a)
+        self.clip(a, m, M, ac)
+        assert_array_strict_equal(a2, ac)
+        self.assert_(a2 is a)
+
+
 class test_allclose_inf(ParametricTestCase):
     rtol = 1e-5
     atol = 1e-8
@@ -724,6 +737,28 @@ class test_allclose_inf(ParametricTestCase):
         assert_array_equal(x,array([inf,1]))
         assert_array_equal(y,array([0,inf]))
 
+class TestStdVar(NumpyTestCase):
+    def setUp(self):
+        self.A = array([1,-1,1,-1])
+        self.real_var = 1
+
+    def test_basic(self):
+        assert_almost_equal(var(self.A),self.real_var)
+        assert_almost_equal(std(self.A)**2,self.real_var)
+    def test_ddof1(self):
+        assert_almost_equal(var(self.A,ddof=1),self.real_var*len(self.A)/float(len(self.A)-1))
+        assert_almost_equal(std(self.A,ddof=1)**2,self.real_var*len(self.A)/float(len(self.A)-1))
+    def test_ddof2(self):
+        assert_almost_equal(var(self.A,ddof=2),self.real_var*len(self.A)/float(len(self.A)-2))
+        assert_almost_equal(std(self.A,ddof=2)**2,self.real_var*len(self.A)/float(len(self.A)-2))
+
+class TestStdVarComplex(NumpyTestCase):
+    def test_basic(self):
+        A = array([1,1.j,-1,-1.j])
+        real_var = 1
+        assert_almost_equal(var(A),real_var)
+        assert_almost_equal(std(A)**2,real_var)
+
 import sys
 if sys.version_info[:2] >= (2, 5):
     set_local_path()
