@@ -4,7 +4,7 @@ set_package_path()
 from f2py_ext import fib2
 del sys.path[0]
 
-class test_fib2(NumpyTestCase):
+class TestFib2(NumpyTestCase):
 
     def check_fib(self):
         assert_array_equal(fib2.fib(6),[0,1,1,2,3,5])
