@@ -5,6 +5,7 @@ set_package_path()
 import numpy.lib;reload(numpy.lib)
 from numpy.lib import *
 from numpy.core import *
+
 del sys.path[0]
 
 class TestAny(NumpyTestCase):
@@ -50,19 +51,70 @@ class TestAverage(NumpyTestCase):
         y4 = ones((4,4))
         y4[0,1] = 0
         y4[1,0] = 2
-        assert_array_equal(y4.mean(0), average(y4, 0))
-        assert_array_equal(y4.mean(1), average(y4, 1))
+        assert_almost_equal(y4.mean(0), average(y4, 0))
+        assert_almost_equal(y4.mean(1), average(y4, 1))
 
         y5 = rand(5,5)
-        assert_array_equal(y5.mean(0), average(y5, 0))
-        assert_array_equal(y5.mean(1), average(y5, 1))
+        assert_almost_equal(y5.mean(0), average(y5, 0))
+        assert_almost_equal(y5.mean(1), average(y5, 1))
 
-    def check_weighted(self):
-        y1 = array([[1,2,3],
-                    [4,5,6]])
-        actual = average(y1,weights=[1,2],axis=0)
+        y6 = matrix(rand(5,5))
+        assert_array_equal(y6.mean(0), average(y6,0))
+
+    def check_weights(self):
+        y = arange(10)
+        w = arange(10)
+        assert_almost_equal(average(y, weights=w), (arange(10)**2).sum()*1./arange(10).sum())
+
+        y1 = array([[1,2,3],[4,5,6]])
+        w0 = [1,2]
+        actual = average(y1,weights=w0,axis=0)
         desired = array([3.,4.,5.])
-        assert_array_equal(actual, desired)
+        assert_almost_equal(actual, desired)
+
+
+        w1 = [0,0,1]
+        desired = array([3., 6.])
+        assert_almost_equal(average(y1, weights=w1, axis=1), desired)
+
+        # This should raise an error. Can we test for that ?
+        # assert_equal(average(y1, weights=w1), 9./2.)
+
+
+        # 2D Case
+        w2 = [[0,0,1],[0,0,2]]
+        desired = array([3., 6.])
+        assert_array_equal(average(y1, weights=w2, axis=1), desired)
+
+        assert_equal(average(y1, weights=w2), 5.)
+
+
+    def check_returned(self):
+        y = array([[1,2,3],[4,5,6]])
+
+        # No weights
+        avg, scl = average(y, returned=True)
+        assert_equal(scl, 6.)
+
+        avg, scl = average(y, 0, returned=True)
+        assert_array_equal(scl, array([2.,2.,2.]))
+
+        avg, scl = average(y, 1, returned=True)
+        assert_array_equal(scl, array([3.,3.]))
+
+        # With weights
+        w0 = [1,2]
+        avg, scl = average(y, weights=w0, axis=0, returned=True)
+        assert_array_equal(scl, array([3., 3., 3.]))
+
+        w1 = [1,2,3]
+        avg, scl = average(y, weights=w1, axis=1, returned=True)
+        assert_array_equal(scl, array([6., 6.]))
+
+        w2 = [[0,0,1],[1,2,3]]
+        avg, scl = average(y, weights=w2, axis=1, returned=True)
+        assert_array_equal(scl, array([1.,6.]))
+
 
 class TestSelect(NumpyTestCase):
     def _select(self,cond,values,default=0):
@@ -376,32 +428,129 @@ class TestSinc(NumpyTestCase):
         assert_array_almost_equal(w,flipud(w),7)
 
 class TestHistogram(NumpyTestCase):
+    import warnings
+    warnings.simplefilter('ignore', FutureWarning)
     def check_simple(self):
         n=100
         v=rand(n)
         (a,b)=histogram(v)
         #check if the sum of the bins equals the number of samples
-        assert(sum(a,axis=0)==n)
-        #check that the bin counts are evenly spaced when the data is from a linear function
+        assert_equal(sum(a,axis=0), n)
+        #check that the bin counts are evenly spaced when the data is from a
+        # linear function
         (a,b)=histogram(linspace(0,10,100))
-        assert(all(a==10))
+        assert_array_equal(a, 10)
+
+    def check_simple_new(self):
+        n=100
+        v=rand(n)
+        (a,b)=histogram(v, new=True)
+        #check if the sum of the bins equals the number of samples
+        assert_equal(sum(a,axis=0), n)
+        #check that the bin counts are evenly spaced when the data is from a
+        # linear function
+        (a,b)=histogram(linspace(0,10,100), new=True)
+        assert_array_equal(a, 10)
+
+    def check_normed_new(self):
+        # Check that the integral of the density equals 1.
+        n = 100
+        v = rand(n)
+        a,b = histogram(v, normed=True, new=True)
+        area = sum(a*diff(b))
+        assert_almost_equal(area, 1)
+
+        # Check with non constant bin width
+        v = rand(n)*10
+        bins = [0,1,5, 9, 10]
+        a,b = histogram(v, bins, normed=True, new=True)
+        area = sum(a*diff(b))
+        assert_almost_equal(area, 1)
+
+
+    def check_outliers_new(self):
+        # Check that outliers are not tallied
+        a = arange(10)+.5
+
+        # Lower outliers
+        h,b = histogram(a, range=[0,9], new=True)
+        assert_equal(h.sum(),9)
+
+        # Upper outliers
+        h,b = histogram(a, range=[1,10], new=True)
+        assert_equal(h.sum(),9)
+
+        # Normalization
+        h,b = histogram(a, range=[1,9], normed=True, new=True)
+        assert_equal((h*diff(b)).sum(),1)
+
+        # Weights
+        w = arange(10)+.5
+        h,b = histogram(a, range=[1,9], weights=w, normed=True, new=True)
+        assert_equal((h*diff(b)).sum(),1)
+
+        h,b = histogram(a, bins=8, range=[1,9], weights=w, new=True)
+        assert_equal(h, w[1:-1])
+
+
+    def check_type_new(self):
+        # Check the type of the returned histogram
+        a = arange(10)+.5
+        h,b = histogram(a, new=True)
+        assert(issubdtype(h.dtype, int))
+
+        h,b = histogram(a, normed=True, new=True)
+        assert(issubdtype(h.dtype, float))
+
+        h,b = histogram(a, weights=ones(10, int), new=True)
+        assert(issubdtype(h.dtype, int))
+
+        h,b = histogram(a, weights=ones(10, float), new=True)
+        assert(issubdtype(h.dtype, float))
+
+
+    def check_weights_new(self):
+        v = rand(100)
+        w = ones(100)*5
+        a,b = histogram(v,new=True)
+        na,nb = histogram(v, normed=True, new=True)
+        wa,wb = histogram(v, weights=w, new=True)
+        nwa,nwb = histogram(v, weights=w, normed=True, new=True)
+        assert_array_almost_equal(a*5, wa)
+        assert_array_almost_equal(na, nwa)
+
+        # Check weights are properly applied.
+        v = linspace(0,10,10)
+        w = concatenate((zeros(5), ones(5)))
+        wa,wb = histogram(v, bins=arange(11),weights=w, new=True)
+        assert_array_almost_equal(wa, w)
+
+        # Check with integer weights
+        wa, wb = histogram([1,2,2,4], bins=4, weights=[4,3,2,1], new=True)
+        assert_array_equal(wa, [4,5,0,1])
+        wa, wb = histogram([1,2,2,4], bins=4, weights=[4,3,2,1], normed=True, new=True)
+        assert_array_equal(wa, array([4,5,0,1])/10./3.*4)
 
 class TestHistogramdd(NumpyTestCase):
     def check_simple(self):
         x = array([[-.5, .5, 1.5], [-.5, 1.5, 2.5], [-.5, 2.5, .5], \
         [.5, .5, 1.5], [.5, 1.5, 2.5], [.5, 2.5, 2.5]])
         H, edges = histogramdd(x, (2,3,3), range = [[-1,1], [0,3], [0,3]])
-        answer = asarray([[[0,1,0], [0,0,1], [1,0,0]], [[0,1,0], [0,0,1], [0,0,1]]])
+        answer = asarray([[[0,1,0], [0,0,1], [1,0,0]], [[0,1,0], [0,0,1],
+            [0,0,1]]])
         assert_array_equal(H,answer)
         # Check normalization
         ed = [[-2,0,2], [0,1,2,3], [0,1,2,3]]
         H, edges = histogramdd(x, bins = ed, normed = True)
         assert(all(H == answer/12.))
         # Check that H has the correct shape.
-        H, edges = histogramdd(x, (2,3,4), range = [[-1,1], [0,3], [0,4]], normed=True)
-        answer = asarray([[[0,1,0,0], [0,0,1,0], [1,0,0,0]], [[0,1,0,0], [0,0,1,0], [0,0,1,0]]])
+        H, edges = histogramdd(x, (2,3,4), range = [[-1,1], [0,3], [0,4]],
+            normed=True)
+        answer = asarray([[[0,1,0,0], [0,0,1,0], [1,0,0,0]], [[0,1,0,0],
+            [0,0,1,0], [0,0,1,0]]])
         assert_array_almost_equal(H, answer/6., 4)
-        # Check that a sequence of arrays is accepted and H has the correct shape.
+        # Check that a sequence of arrays is accepted and H has the correct
+        # shape.
         z = [squeeze(y) for y in split(x,3,axis=1)]
         H, edges = histogramdd(z, bins=(4,3,2),range=[[-2,2], [0,3], [0,2]])
         answer = asarray([[[0,0],[0,0],[0,0]],
@@ -415,10 +564,28 @@ class TestHistogramdd(NumpyTestCase):
         H,edges = histogramdd([arange(5), arange(5), arange(5)], 5)
         assert_array_equal(H, Z)
 
-    def check_shape(self):
-        x = rand(100,3)
-        hist3d, edges = histogramdd(x, bins = (5, 7, 6))
-        assert_array_equal(hist3d.shape, (5,7,6))
+    def check_shape_3d(self):
+        # All possible permutations for bins of different lengths in 3D.
+        bins = ((5, 4, 6), (6, 4, 5), (5, 6, 4), (4, 6, 5), (6, 5, 4),
+            (4, 5, 6))
+        r = rand(10,3)
+        for b in bins:
+            H, edges = histogramdd(r, b)
+            assert(H.shape == b)
+
+    def check_shape_4d(self):
+        # All possible permutations for bins of different lengths in 4D.
+        bins = ((7, 4, 5, 6), (4, 5, 7, 6), (5, 6, 4, 7), (7, 6, 5, 4),
+            (5, 7, 6, 4), (4, 6, 7, 5), (6, 5, 7, 4), (7, 5, 4, 6),
+            (7, 4, 6, 5), (6, 4, 7, 5), (6, 7, 5, 4), (4, 6, 5, 7),
+            (4, 7, 5, 6), (5, 4, 6, 7), (5, 7, 4, 6), (6, 7, 4, 5),
+            (6, 5, 4, 7), (4, 7, 6, 5), (4, 5, 6, 7), (7, 6, 4, 5),
+            (5, 4, 7, 6), (5, 6, 7, 4), (6, 4, 5, 7), (7, 5, 6, 4))
+
+        r = rand(10,4)
+        for b in bins:
+            H, edges = histogramdd(r, b)
+            assert(H.shape == b)
 
     def check_weights(self):
         v = rand(100,2)
