@@ -3,7 +3,7 @@ set_package_path()
 from numpy import array, ones, r_, mgrid
 restore_path()
 
-class test_grid(NumpyTestCase):
+class TestGrid(NumpyTestCase):
     def check_basic(self):
         a = mgrid[-1:1:10j]
         b = mgrid[-1:1:0.1]
@@ -28,13 +28,21 @@ class test_grid(NumpyTestCase):
         assert_array_almost_equal(d[0,1,:]-d[0,0,:], 0.1*ones(20,'d'),11)
         assert_array_almost_equal(d[1,:,1]-d[1,:,0], 0.2*ones(20,'d'),11)
 
-class test_concatenator(NumpyTestCase):
+class TestConcatenator(NumpyTestCase):
     def check_1d(self):
         assert_array_equal(r_[1,2,3,4,5,6],array([1,2,3,4,5,6]))
         b = ones(5)
         c = r_[b,0,0,b]
         assert_array_equal(c,[1,1,1,1,1,0,0,1,1,1,1,1])
 
+    def check_mixed_type(self):
+        g = r_[10.1, 1:10]
+        assert(g.dtype == 'f8')
+
+    def check_more_mixed_type(self):
+        g = r_[-10.1, array([1]), array([2,3,4]), 10.0]
+        assert(g.dtype == 'f8')
+
     def check_2d(self):
         b = rand(5,5)
         c = rand(5,5)
