@@ -5,13 +5,13 @@ storing results in an output array.
 __all__ = ['fix', 'isneginf', 'isposinf', 'log2']
 
 import numpy.core.numeric as nx
-from numpy.core.numeric import asarray, empty, isinf, signbit
+from numpy.core.numeric import asarray, empty, isinf, signbit, asanyarray
 import numpy.core.umath as umath
 
 def fix(x, y=None):
     """ Round x to nearest integer towards zero.
     """
-    x = asarray(x)
+    x = asanyarray(x)
     if y is None:
         y = nx.floor(x)
     else:
@@ -29,6 +29,7 @@ def isposinf(x, y=None):
     If y is an array, the result replaces the contents of y.
     """
     if y is None:
+        x = asarray(x)
         y = empty(x.shape, dtype=nx.bool_)
     umath.logical_and(isinf(x), ~signbit(x), y)
     return y
@@ -39,6 +40,7 @@ def isneginf(x, y=None):
     If y is an array, the result replaces the contents of y.
     """
     if y is None:
+        x = asarray(x)
         y = empty(x.shape, dtype=nx.bool_)
     umath.logical_and(isinf(x), signbit(x), y)
     return y
@@ -49,7 +51,7 @@ def log2(x, y=None):
 
     If y is an array, the result replaces the contents of y.
     """
-    x = asarray(x)
+    x = asanyarray(x)
     if y is None:
         y = umath.log(x)
     else:
