@@ -4,6 +4,7 @@ import sys
 import imp
 import glob
 import types
+import shlex
 import unittest
 import traceback
 import warnings
@@ -108,6 +109,8 @@ class _dummy_stream:
         self.data.append(message)
     def writeln(self,message):
         self.write(message+'\n')
+    def flush(self):
+        self.stream.flush()
 
 
 class NumpyTestCase (unittest.TestCase):
@@ -130,7 +133,8 @@ class NumpyTestCase (unittest.TestCase):
         return 0.01*elapsed
 
     def __call__(self, result=None):
-        if result is None:
+        if result is None or not hasattr(result, 'errors') \
+                or not hasattr(result, 'stream'):
             return unittest.TestCase.__call__(self, result)
 
         nof_errors = len(result.errors)
@@ -239,24 +243,24 @@ class NumpyTest:
 
     <package> is package name or its module object.
 
-    Package is supposed to contain a directory tests/
-    with test_*.py files where * refers to the names of submodules.
-    See .rename() method to redefine name mapping between test_*.py files
-    and names of submodules. Pattern test_*.py can be overwritten by
-    redefining .get_testfile() method.
+    Package is supposed to contain a directory tests/ with test_*.py
+    files where * refers to the names of submodules.  See .rename()
+    method to redefine name mapping between test_*.py files and names of
+    submodules. Pattern test_*.py can be overwritten by redefining
+    .get_testfile() method.
 
-    test_*.py files are supposed to define a classes, derived
-    from NumpyTestCase or unittest.TestCase, with methods having
-    names starting with test or bench or check. The names of TestCase
-    classes must have a prefix test. This can be overwritten by
-    redefining .check_testcase_name() method.
+    test_*.py files are supposed to define a classes, derived from
+    NumpyTestCase or unittest.TestCase, with methods having names
+    starting with test or bench or check. The names of TestCase classes
+    must have a prefix test. This can be overwritten by redefining
+    .check_testcase_name() method.
 
     And that is it! No need to implement test or test_suite functions
     in each .py file.
 
-    Also old styled test_suite(level=1) hooks are supported.
+    Old-style test_suite(level=1) hooks are also supported.
     """
-    _check_testcase_name = re.compile(r'test.*').match
+    _check_testcase_name = re.compile(r'test.*|Test.*').match
     def check_testcase_name(self, name):
         """ Return True if name matches TestCase class.
         """
@@ -293,9 +297,14 @@ class NumpyTest:
         self._rename_map = {}
 
     def rename(self, **kws):
-        """ Apply renaming submodule test file test_<name>.py to test_<newname>.py.
-        Usage: self.rename(name='newname') before calling self.test() method.
-        If 'newname' is None, then no tests will be executed for a given module.
+        """Apply renaming submodule test file test_<name>.py to
+        test_<newname>.py.
+
+        Usage: self.rename(name='newname') before calling the
+        self.test() method.
+
+        If 'newname' is None, then no tests will be executed for a given
+        module.
         """
         for k,v in kws.items():
             self._rename_map[k] = v
@@ -373,7 +382,7 @@ class NumpyTest:
         test_dir_module = parent_module_name+'.tests'
         test_module_name = test_dir_module+'.'+test_module_name
 
-        if not sys.modules.has_key(test_dir_module):
+        if test_dir_module not in sys.modules:
             sys.modules[test_dir_module] = imp.new_module(test_dir_module)
 
         old_sys_path = sys.path[:]
@@ -408,9 +417,13 @@ class NumpyTest:
                 suite = obj(mthname)
                 if getattr(suite,'isrunnable',lambda mthname:1)(mthname):
                     suite_list.append(suite)
+        matched_suite_list = [suite for suite in suite_list \
+                              if self.testcase_match(suite.id()\
+                                                     .replace('__main__.',''))]
         if verbosity>=0:
-            self.info('  Found %s tests for %s' % (len(suite_list), module_name))
-        return suite_list
+            self.info('  Found %s/%s tests for %s' \
+                      % (len(matched_suite_list), len(suite_list), module_name))
+        return matched_suite_list
 
     def _test_suite_from_modules(self, this_package, level, verbosity):
         package_name = this_package.__name__
@@ -453,7 +466,8 @@ class NumpyTest:
             d = os.path.join(d, 'tests')
             if not os.path.isdir(d):
                 continue
-            if test_dirs_names.has_key(d): continue
+            if d in test_dirs_names:
+                continue
             test_dir_module = '.'.join(name.split('.')[:-1]+['tests'])
             test_dirs_names[d] = test_dir_module
 
@@ -467,7 +481,7 @@ class NumpyTest:
         for test_dir in test_dirs:
             test_dir_module = test_dirs_names[test_dir]
 
-            if not sys.modules.has_key(test_dir_module):
+            if test_dir_module not in sys.modules:
                 sys.modules[test_dir_module] = imp.new_module(test_dir_module)
 
             for fn in os.listdir(test_dir):
@@ -513,7 +527,8 @@ class NumpyTest:
         all_tests = unittest.TestSuite(suite_list)
         return all_tests
 
-    def test(self, level=1, verbosity=1, all=False):
+    def test(self, level=1, verbosity=1, all=True, sys_argv=[],
+             testcase_pattern='.*'):
         """Run Numpy module test suite with level and verbosity.
 
         level:
@@ -533,12 +548,17 @@ class NumpyTest:
           True            --- run all test files (like self.testall())
           False (default) --- only run test files associated with a module
 
-        It is assumed (when all=False) that package tests suite follows the
-        following convention: for each package module, there exists file
-        <packagepath>/tests/test_<modulename>.py that defines TestCase classes
-        (with names having prefix 'test_') with methods (with names having
-        prefixes 'check_' or 'bench_'); each of these methods are called when
-        running unit tests.
+        sys_argv          --- replacement of sys.argv[1:] during running
+                              tests.
+
+        testcase_pattern  --- run only tests that match given pattern.
+
+        It is assumed (when all=False) that package tests suite follows
+        the following convention: for each package module, there exists
+        file <packagepath>/tests/test_<modulename>.py that defines
+        TestCase classes (with names having prefix 'test_') with methods
+        (with names having prefixes 'check_' or 'bench_'); each of these
+        methods are called when running unit tests.
         """
         if level is None: # Do nothing.
             return
@@ -548,6 +568,8 @@ class NumpyTest:
         else:
             this_package = self.package
 
+        self.testcase_match = re.compile(testcase_pattern).match
+
         if all:
             all_tests = self._test_suite_from_all_tests(this_package,
                                                         level, verbosity)
@@ -559,16 +581,19 @@ class NumpyTest:
             return all_tests
 
         runner = unittest.TextTestRunner(verbosity=verbosity)
+        old_sys_argv = sys.argv[1:]
+        sys.argv[1:] = sys_argv
         # Use the builtin displayhook. If the tests are being run
         # under IPython (for instance), any doctest test suites will
         # fail otherwise.
         old_displayhook = sys.displayhook
         sys.displayhook = sys.__displayhook__
         try:
-            runner.run(all_tests)
+            r = runner.run(all_tests)
         finally:
             sys.displayhook = old_displayhook
-        return runner
+        sys.argv[1:] = old_sys_argv
+        return r
 
     def testall(self, level=1,verbosity=1):
         """ Run Numpy module test suite with level and verbosity.
@@ -600,7 +625,9 @@ class NumpyTest:
         except ImportError:
             self.warn('Failed to import optparse module, ignoring.')
             return self.test()
-        usage = r'usage: %prog [-v <verbosity>] [-l <level>]'
+        usage = r'usage: %prog [-v <verbosity>] [-l <level>]'\
+                r' [-s "<replacement of sys.argv[1:]>"]'\
+                r' [-t "<testcase pattern>"]'
         parser = OptionParser(usage)
         parser.add_option("-v", "--verbosity",
                           action="store",
@@ -612,9 +639,20 @@ class NumpyTest:
                           dest="level",
                           default=1,
                           type='int')
+        parser.add_option("-s", "--sys-argv",
+                          action="store",
+                          dest="sys_argv",
+                          default='',
+                          type='string')
+        parser.add_option("-t", "--testcase-pattern",
+                          action="store",
+                          dest="testcase_pattern",
+                          default=r'.*',
+                          type='string')
         (options, args) = parser.parse_args()
-        self.test(options.level,options.verbosity)
-        return
+        return self.test(options.level,options.verbosity,
+                         sys_argv=shlex.split(options.sys_argv or ''),
+                         testcase_pattern=options.testcase_pattern)
 
     def warn(self, message):
         from numpy.distutils.misc_util import yellow_text
